@@ -2,32 +2,32 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="23"/>
+        <location filename="../mainwindow.cpp" line="24"/>
         <source>Restart Fluxbox</source>
         <translation>Käynnistä Fluxbox</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="27"/>
+        <location filename="../mainwindow.cpp" line="28"/>
         <source>Lock Screen</source>
         <translation>Lukitse näyttö</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="25"/>
+        <location filename="../mainwindow.cpp" line="26"/>
         <source>Log Out</source>
         <translation>Kirjaudu ulos</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="33"/>
+        <location filename="../mainwindow.cpp" line="34"/>
         <source>Suspend</source>
         <translation>Keskeytä</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="29"/>
+        <location filename="../mainwindow.cpp" line="30"/>
         <source>Reboot</source>
         <translation>Käynnistä uudelleen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="31"/>
+        <location filename="../mainwindow.cpp" line="32"/>
         <source>Shutdown</source>
         <translation>Sammuta</translation>
     </message>
@@ -35,84 +35,89 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="46"/>
-        <location filename="../main.cpp" line="54"/>
+        <location filename="../main.cpp" line="48"/>
+        <location filename="../main.cpp" line="56"/>
         <source>Pop-up with exit options for MX Fluxbox</source>
         <translation>Ponnahdusikkuna, jossa on MX Fluxbox poistumisen valinnat</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="47"/>
+        <location filename="../main.cpp" line="49"/>
         <source>Display buttons in a vertical window</source>
         <translation>Näytä painikkeet pystysuuntaan ikkunassa</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="48"/>
+        <location filename="../main.cpp" line="50"/>
         <source>Display buttons in a horizontal window</source>
         <translation>Näytä painikkeet vaakasuuntaan ikkunassa</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="49"/>
+        <location filename="../main.cpp" line="51"/>
         <source>Timeout duration in seconds</source>
         <translation>Katkaisun kesto sekunteina</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="50"/>
+        <location filename="../main.cpp" line="52"/>
         <source>use -v, --vertical to display buttons vertically
 use -h, --horizontal to display buttons horizontally.</source>
         <translation>käytä -v, --vertical näyttää painikkeet pystysuunnassa
 käytä -h, --horizontal näyttää painikkeet vaakasuunnassa.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="57"/>
         <source>Usage: exit-options [options]
 </source>
         <translation>Käyttö: exit-options [options]
 </translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="56"/>
+        <location filename="../main.cpp" line="58"/>
         <source>Options:</source>
         <translation>Asetukset:</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="57"/>
+        <location filename="../main.cpp" line="59"/>
         <source>  -h, --horizontal	 Option to display buttons horizontally</source>
         <translation>  -h, --horizontal	 Asetus näyttää painikkeet vaakasuunnassa</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../main.cpp" line="60"/>
         <source>  -v, --vertical	 Option to display buttons vertically</source>
         <translation>  -v, --vertical	 Asetus näyttää painikkeet pystysuunnassa</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="61"/>
         <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
 </source>
         <translation>  -t, --timeout &lt;sec&gt;	 Katkaisun kesto sekunteina
 </translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="60"/>
+        <location filename="../main.cpp" line="62"/>
         <source>The display orientation option used will be remembered and used the next time you start the app</source>
         <translation>Näytön suunnan asetus muistetaan ja käytetään seuraavan kerran kun käynnistät sovelluksen</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="62"/>
+        <location filename="../main.cpp" line="64"/>
         <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
         <translation>Vaihtoehtoisesti aseta vailinta &apos;layout=horizontal&apos; tai &apos;layout=vertical&apos; tiedostossa ~/.config/MX-Linux/exit-options.conf</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="66"/>
+        <location filename="../main.cpp" line="67"/>
         <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
         <translation>Aseta katkaisu tiedostossa exit-options.conf käyttämällä &apos;timeout=X&apos;, jossa X on katkaisuaika sekunteina.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="69"/>
+        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="71"/>
         <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
         <translation>Voit määrittää omia kuvakkeita lisäämällä IconName=/path/iconame.ext exit-options.conf tiedostoon. Kuvakkeiden nimet, jotka yhdistät: %1</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="73"/>
+        <location filename="../main.cpp" line="75"/>
         <source>Other options that can be set in the exit-options.conf file: %1</source>
         <translation>Muut asetukset, jotka voi asettaa tiedostossa exit-options.conf: %1</translation>
     </message>
