@@ -2,32 +2,32 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="23"/>
+        <location filename="../mainwindow.cpp" line="24"/>
         <source>Restart Fluxbox</source>
         <translation>Omstart av Fluxbox</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="27"/>
+        <location filename="../mainwindow.cpp" line="28"/>
         <source>Lock Screen</source>
         <translation>Lås skjermen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="25"/>
+        <location filename="../mainwindow.cpp" line="26"/>
         <source>Log Out</source>
         <translation>Logg ut</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="33"/>
+        <location filename="../mainwindow.cpp" line="34"/>
         <source>Suspend</source>
         <translation>Hvilemodus</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="29"/>
+        <location filename="../mainwindow.cpp" line="30"/>
         <source>Reboot</source>
         <translation>Omstart</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="31"/>
+        <location filename="../mainwindow.cpp" line="32"/>
         <source>Shutdown</source>
         <translation>Avslutter</translation>
     </message>
@@ -35,84 +35,89 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="46"/>
-        <location filename="../main.cpp" line="54"/>
+        <location filename="../main.cpp" line="48"/>
+        <location filename="../main.cpp" line="56"/>
         <source>Pop-up with exit options for MX Fluxbox</source>
         <translation>Sprettoppvindu med avslutningsalternativer for MX Fluxbox</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="47"/>
+        <location filename="../main.cpp" line="49"/>
         <source>Display buttons in a vertical window</source>
         <translation>Vis knapper i et loddrett vindu</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="48"/>
+        <location filename="../main.cpp" line="50"/>
         <source>Display buttons in a horizontal window</source>
         <translation>Vis knapper i et vannrett vindu</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="49"/>
+        <location filename="../main.cpp" line="51"/>
         <source>Timeout duration in seconds</source>
         <translation>Tidsavbrudd i sekunder</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="50"/>
+        <location filename="../main.cpp" line="52"/>
         <source>use -v, --vertical to display buttons vertically
 use -h, --horizontal to display buttons horizontally.</source>
         <translation>bruk -v eller --vertical for å vise knapper loddrett
 bruk -h eller --horizontal for å vise knapper vannrett.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="57"/>
         <source>Usage: exit-options [options]
 </source>
         <translation>Bruk: exit-options [alternativer]
 </translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="56"/>
+        <location filename="../main.cpp" line="58"/>
         <source>Options:</source>
         <translation>Alternativer:</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="57"/>
+        <location filename="../main.cpp" line="59"/>
         <source>  -h, --horizontal	 Option to display buttons horizontally</source>
         <translation>-h, --horizontal	 Vis knapper vannrett</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../main.cpp" line="60"/>
         <source>  -v, --vertical	 Option to display buttons vertically</source>
         <translation>-v, --vertical	 Vis knapper loddrett</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="61"/>
         <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
 </source>
         <translation>-t, --timeout &lt;sec&gt;	Tidsavbrudd i sekunder
 </translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="60"/>
+        <location filename="../main.cpp" line="62"/>
         <source>The display orientation option used will be remembered and used the next time you start the app</source>
         <translation>Visningsretningen vil huskes og brukes neste gang programmet startes</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="62"/>
+        <location filename="../main.cpp" line="64"/>
         <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
         <translation>Dette kan også angis som &apos;layout=horizontal&apos; eller &apos;layout=vertical&apos; i ~/.config/MX-Linux/exit-options.conf</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="66"/>
+        <location filename="../main.cpp" line="67"/>
         <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
         <translation>Skriv «timeout=X» i exit-options.conf for å velge tidsavbrudd (X er tidsavbruddet i sekunder).</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="69"/>
+        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="71"/>
         <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
         <translation>Definer selvvalgte ikoner ved å legge til IconName=/sti/ikonnavn.utv i fila exit-options.conf. Hvilke ikoner som overstyres: %1</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="73"/>
+        <location filename="../main.cpp" line="75"/>
         <source>Other options that can be set in the exit-options.conf file: %1</source>
         <translation>Andre alternativer som kan angis i fila «exit-options.conf»: %1</translation>
     </message>
