@@ -2,32 +2,32 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="23"/>
+        <location filename="../mainwindow.cpp" line="24"/>
         <source>Restart Fluxbox</source>
         <translation>Reiniciar Fluxbox</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="27"/>
+        <location filename="../mainwindow.cpp" line="28"/>
         <source>Lock Screen</source>
         <translation>Bloquear ecrã</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="25"/>
+        <location filename="../mainwindow.cpp" line="26"/>
         <source>Log Out</source>
         <translation>Terminar sessão</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="33"/>
+        <location filename="../mainwindow.cpp" line="34"/>
         <source>Suspend</source>
         <translation>Suspender</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="29"/>
+        <location filename="../mainwindow.cpp" line="30"/>
         <source>Reboot</source>
         <translation>Reiniciar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="31"/>
+        <location filename="../mainwindow.cpp" line="32"/>
         <source>Shutdown</source>
         <translation>Encerrar</translation>
     </message>
@@ -35,84 +35,89 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="46"/>
-        <location filename="../main.cpp" line="54"/>
+        <location filename="../main.cpp" line="48"/>
+        <location filename="../main.cpp" line="56"/>
         <source>Pop-up with exit options for MX Fluxbox</source>
         <translation>Janela com as opções de saída do MX Fluxbox</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="47"/>
+        <location filename="../main.cpp" line="49"/>
         <source>Display buttons in a vertical window</source>
         <translation>Mostrar botões numa janela vertical</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="48"/>
+        <location filename="../main.cpp" line="50"/>
         <source>Display buttons in a horizontal window</source>
         <translation>Mostrar botões numa janela horizontal</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="49"/>
+        <location filename="../main.cpp" line="51"/>
         <source>Timeout duration in seconds</source>
         <translation>Tempo de espera em segundos</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="50"/>
+        <location filename="../main.cpp" line="52"/>
         <source>use -v, --vertical to display buttons vertically
 use -h, --horizontal to display buttons horizontally.</source>
         <translation>usar ‘-v’ ou ‘--vertical’ para mostrar botões na vertical.
 usar ‘-h’ ou ‘--horizontal’ para mostrar botões na horizontal.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="57"/>
         <source>Usage: exit-options [options]
 </source>
         <translation>Utilização das opções de saída: exit-options [opções]
 </translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="56"/>
+        <location filename="../main.cpp" line="58"/>
         <source>Options:</source>
         <translation>Opções: </translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="57"/>
+        <location filename="../main.cpp" line="59"/>
         <source>  -h, --horizontal	 Option to display buttons horizontally</source>
         <translation>  -h, --horizontal	 Opção para mostrar botões na horizontal</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../main.cpp" line="60"/>
         <source>  -v, --vertical	 Option to display buttons vertically</source>
         <translation>  -v, --vertical	 Opção para mostrar os botões na vertical</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="61"/>
         <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
 </source>
         <translation>  -t, --timeout &lt;sec&gt;	 Tempo de espera em segundos
 </translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="60"/>
+        <location filename="../main.cpp" line="62"/>
         <source>The display orientation option used will be remembered and used the next time you start the app</source>
         <translation>A opção de orientação da visualização será memorizada e utilizada na próxima vez que iniciar esta aplicação</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="62"/>
+        <location filename="../main.cpp" line="64"/>
         <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
         <translation>Em alternativa, pode definir a opção ‘layout=horizontal’ ou ‘layout=vertical’ no ficheiro  de configuração ~/.config/MX-Linux/exit-options.conf</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="66"/>
+        <location filename="../main.cpp" line="67"/>
         <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
         <translation>Para configurar o tempo limite em exit-options.conf use &apos;timeout=X&apos; onde X é o tempo em segundos.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="69"/>
+        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
+        <translation>Também pode usar &apos;timeout=off&apos; para desligar o temporizador.</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="71"/>
         <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
         <translation>Pode definir os ícones personalizados adicionando o parâmetro ‘IconName=/path/iconame.ext’ no ficheiro de configuração ‘exit-options.conf’. Os nomes dos ícones que pode remapear são: %1</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="73"/>
+        <location filename="../main.cpp" line="75"/>
         <source>Other options that can be set in the exit-options.conf file: %1</source>
         <translation>Outras opções que podem ser definidas no ficheiro de configuração ‘exit-options.conf’ são: %1</translation>
     </message>
