@@ -2,32 +2,32 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="23"/>
+        <location filename="../mainwindow.cpp" line="24"/>
         <source>Restart Fluxbox</source>
         <translation>Ponovno zaženi Fluxbox</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="27"/>
+        <location filename="../mainwindow.cpp" line="28"/>
         <source>Lock Screen</source>
         <translation>Zakleni zaslon</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="25"/>
+        <location filename="../mainwindow.cpp" line="26"/>
         <source>Log Out</source>
         <translation>Odjava</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="33"/>
+        <location filename="../mainwindow.cpp" line="34"/>
         <source>Suspend</source>
         <translation>Zaustavitev</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="29"/>
+        <location filename="../mainwindow.cpp" line="30"/>
         <source>Reboot</source>
         <translation>Ponovni zagon</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="31"/>
+        <location filename="../mainwindow.cpp" line="32"/>
         <source>Shutdown</source>
         <translation>Izklop</translation>
     </message>
@@ -35,82 +35,87 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="46"/>
-        <location filename="../main.cpp" line="54"/>
+        <location filename="../main.cpp" line="48"/>
+        <location filename="../main.cpp" line="56"/>
         <source>Pop-up with exit options for MX Fluxbox</source>
         <translation>Pojavno okno z možnostmi za izhod iz MX Fluxbox</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="47"/>
+        <location filename="../main.cpp" line="49"/>
         <source>Display buttons in a vertical window</source>
         <translation>Prikaži gumbe v navpičnem oknu</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="48"/>
+        <location filename="../main.cpp" line="50"/>
         <source>Display buttons in a horizontal window</source>
         <translation>Prikaži gumbe v vodoravnem oknu</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="49"/>
+        <location filename="../main.cpp" line="51"/>
         <source>Timeout duration in seconds</source>
         <translation>Časovna omejitev v sekundah</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="50"/>
+        <location filename="../main.cpp" line="52"/>
         <source>use -v, --vertical to display buttons vertically
 use -h, --horizontal to display buttons horizontally.</source>
         <translation>uporabite -v, -vertical za navpični prikaz gumbov
 uporabite -h, -horizontal za vodoravni prikaz gumbov</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="57"/>
         <source>Usage: exit-options [options]
 </source>
         <translation>Uporaba: exit-options [možnosti]</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="56"/>
+        <location filename="../main.cpp" line="58"/>
         <source>Options:</source>
         <translation>Možnosti:</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="57"/>
+        <location filename="../main.cpp" line="59"/>
         <source>  -h, --horizontal	 Option to display buttons horizontally</source>
         <translation>-h, -horizontal	 Vodoravni prikaz gumbov</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="58"/>
+        <location filename="../main.cpp" line="60"/>
         <source>  -v, --vertical	 Option to display buttons vertically</source>
         <translation>-v, -vertical	 Navpični prikaz gumbov</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="61"/>
         <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
 </source>
         <translation>-t, -timeout &lt;sec&gt;	Časovna omejitev v sekundah</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="60"/>
+        <location filename="../main.cpp" line="62"/>
         <source>The display orientation option used will be remembered and used the next time you start the app</source>
         <translation>Orientacija prikaza se bo shranila in bo uporabljena ob naslednjem zagonu aplikacije</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="62"/>
+        <location filename="../main.cpp" line="64"/>
         <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
         <translation>Namesto tega lahko nastavite &quot;layout=horizontal&quot; ali &quot;layout=vertical&quot; v ~/.config/MX-Linux/exit-options.conf</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="66"/>
+        <location filename="../main.cpp" line="67"/>
         <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
         <translation>Za določitev časovne omejitve v  exit-options.conf , uporabite &apos;timeout=X&apos;, kjer je X časovna omejitev v sekundah.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="69"/>
+        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="71"/>
         <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
         <translation>Ikone lahko določite po meri z dodajanjem IconName=/pot/imeikone.ext v datoteko exit-options.conf. Ime ikon, ki jih premapirate: %1</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="73"/>
+        <location filename="../main.cpp" line="75"/>
         <source>Other options that can be set in the exit-options.conf file: %1</source>
         <translation>Druge možnosti, ki jih je možno določiti v datoteki exit-options.conf: %1</translation>
     </message>
